@@ -158,8 +158,8 @@ class Config(dict):
         logger.info(f"Put {ct} values from environment variables into configuration")
         return True
 
-    def apply_dict(self, other, source ='dict'):
-        ct=0
+    def apply_dict(self, other, source="dict"):
+        ct = 0
         for key, value in self.items():
             file_value = other.get(key, None)
             if file_value:
@@ -171,8 +171,7 @@ class Config(dict):
                 # logger.warning(f"WARNING: No {key} in file, using last value '{value}'")
                 pass
         return ct
-        
-    
+
     """Helper to load configuration values from configuration file in json format"""
 
     def apply_config_file(self, filename, create_if_missing=True):
