@@ -27,6 +27,9 @@ def file_contains_str(filename, str):
 
 
 def file_contains_bytes(filename, bytes):
+    # mmap does not work for empty files
+    if os.stat(filename).st_size == 0:
+        return False
     with open(filename, "rb", 0) as file, mmap.mmap(file.fileno(), 0, access=mmap.ACCESS_READ) as s:
         if s.find(bytes) != -1:
             return True
